library(shiny)
library(ggplot2)
library(plotly)

ui <- fluidPage(
  tags$div(
    class = "wrapper",
    tags$style(type = "text/css", ".wrapper {padding: 30px}"),
    textInput(inputId = "inputTitle", label = "Plot title:", value = "MTCars visualization"),
    varSelectInput(inputId = "dropdownX", label = "X-axis", data = mtcars),
    varSelectInput(inputId = "dropdownY", label = "Y-axis", data = mtcars),
    plotlyOutput(outputId = "chart")
  )
)

server <- function(input, output) {
  output$chart <- renderPlotly({
    col_x <- sym(input$dropdownX)
    col_y <- sym(input$dropdownY)

    p <- ggplot(mtcars, aes(x = !!col_x, y = !!col_y)) +
      geom_point() +
      labs(title = input$inputTitle)
    ggplotly(p)
  })
}

shinyApp(ui, server)
